==> segment-wrapper-2.21.0.tgz: package/lib/syncPixels.js <==
import { getConfig } from './getConfig';
/**
 * Create the URL of Demdex with a specified Marketing Cloud Visitor Id
 * @param {String} mcvid Marketing Cloud Visitor Id
 * @return {String} URL
 */

var createSyncPixelsUrl = function createSyncPixelsUrl(mcvid) {
  return "https://mpispain.demdex.net/event?d_mid=" + mcvid + "&d_orgid=05FF6243578784B37F000101%40AdobeOrg&d_rtbd=json&d_full=1&d_cts=2";
};
/**
 * Create a pixel by using a image src and log the info with the used ids
 * @param {{ ids: number[], pixelName: String, src: String}} params
 * @return {Promise}
 */


var createPixel = function createPixel(_ref) {
  var ids = _ref.ids,
      pixelName = _ref.pixelName,
      src = _ref.src;
  var img = new window.Image();
  img.src = src;
  return new Promise(function (resolve, reject) {
    img.onload = function () {
      console.info("Create segment in " + pixelName, ids);
      resolve();
    };

    img.onerror = function () {
      var err = "Error creating segments in " + pixelName;
      console.error(err);
      reject(err);
    };
  });
};
/**
 * Sync with Facebook Ads Pixel
 * @param {string} pixelId
 * @param {number[]} ids
 * @return {Promise}
 */


var syncWithFacebook = function syncWithFacebook(pixelId, ids) {
  if (!pixelId) return Promise.resolve();
  var qs = ids.join(',');
  var src = "https://www.facebook.com/tr/?id=" + pixelId + "&ev=Adobe-Audience-Manager-Segment&cd[segID]=" + qs + "&noscript=1";
  return createPixel({
    ids: ids,
    pixelName: 'Facebook Ads',
    src: src
  });
};
/**
 * Sync with Google Ads Pixel
 * @param {string} pixelId
 * @param {number[]} ids
 * @return {Promise}
 */


var syncWithGoogle = function syncWithGoogle(pixelId, ids) {
  if (!pixelId) return Promise.resolve();
  var qs = ids.join(';aam=');
  var src = "https://googleads.g.doubleclick.net/pagead/viewthroughconversion/" + pixelId + "/?guid=ON&script=0&data=aam=" + qs + "&value=0";
  return createPixel({
    ids: ids,
    pixelName: 'Google Ads',
    src: src
  });
};
/**
 * Extract Ids from Demdex API response
 * @param {object} json
 * @return {String}
 */


var extractStringIds = function extractStringIds(json) {
  return json.stuff && json.stuff[0] && json.stuff[0].cv || '';
};
/**
 * Retrieve ids from Demdex API and
 * @param {String} mcvid Marketing Cloud Visitor Id
 * @return {Promise}
 */


export var syncPixels = function syncPixels(mcvid) {
  // check if we have a Marketing Cloud Visitor Id before continuing
  if (!mcvid) return Promise.resolve(); // check if pixels ids are configured before continuing

  var _ref2 = getConfig('segmentWrapper') || {},
      facebookPixelId = _ref2.facebookPixelId,
      googleAdsPixelId = _ref2.googleAdsPixelId;

  if (!facebookPixelId && !googleAdsPixelId) return Promise.resolve(); // if we have a MCVID and pixels are configured, proceed to sync pixels

  return window.fetch(createSyncPixelsUrl(mcvid)).then(function (res) {
    return res.json();
  }).then(extractStringIds).then(function (stringIds) {
    if (stringIds) {
      var ids = stringIds.split(/(\d+)/).map(function (str) {
        return +str;
      }).filter(Boolean);
      return Promise.all([syncWithGoogle(googleAdsPixelId, ids), syncWithFacebook(facebookPixelId, ids)]);
    }
  });
};

==> segment-wrapper-2.24.0.tgz: package/lib/syncPixels.js <==
import { getConfig } from './getConfig';
/**
 * Create the URL of Demdex with a specified Marketing Cloud Visitor Id
 * @param {String} mcvid Marketing Cloud Visitor Id
 * @return {String} URL
 */

var createSyncPixelsUrl = function createSyncPixelsUrl(mcvid) {
  return "https://mpispain.demdex.net/event?d_mid=" + mcvid + "&d_orgid=05FF6243578784B37F000101%40AdobeOrg&d_rtbd=json&d_full=1&d_cts=2";
};
/**
 * Create a pixel by using a image src and log the info with the used ids
 * @param {{ ids: number[], pixelName: String, src: String}} params
 * @return {Promise}
 */


var createPixel = function createPixel(_ref) {
  var ids = _ref.ids,
      pixelName = _ref.pixelName,
      src = _ref.src;
  var img = new window.Image();
  img.src = src;
  return new Promise(function (resolve, reject) {
    img.onload = function () {
      console.info("Create segment in " + pixelName, ids);
      resolve();
    };

    img.onerror = function () {
      var err = "Error creating segments in " + pixelName;
      console.error(err);
      reject(err);
    };
  });
};
/**
 * Sync with Facebook Ads Pixel
 * @param {string} pixelId
 * @param {number[]} ids
 * @return {Promise}
 */


var syncWithFacebook = function syncWithFacebook(pixelId, ids) {
  if (!pixelId) return Promise.resolve();
  var qs = ids.join(',');
  var src = "https://www.facebook.com/tr/?id=" + pixelId + "&ev=Adobe-Audience-Manager-Segment&cd[segID]=" + qs + "&noscript=1";
  return createPixel({
    ids: ids,
    pixelName: 'Facebook Ads',
    src: src
  });
};
/**
 * Sync with Google Ads Pixel
 * @param {string} pixelId
 * @param {number[]} ids
 * @return {Promise}
 */


var syncWithGoogle = function syncWithGoogle(pixelId, ids) {
  if (!pixelId) return Promise.resolve();
  var qs = ids.join(';aam=');
  var src = "https://googleads.g.doubleclick.net/pagead/viewthroughconversion/" + pixelId + "/?guid=ON&script=0&data=aam=" + qs + "&value=0";
  return createPixel({
    ids: ids,
    pixelName: 'Google Ads',
    src: src
  });
};
/**
 * Extract Ids from Demdex API response
 * @param {object} json
 * @return {String}
 */


var extractStringIds = function extractStringIds(json) {
  return json.stuff && json.stuff[0] && json.stuff[0].cv || '';
};
/**
 * Retrieve ids from Demdex API and
 * @param {String} mcvid Marketing Cloud Visitor Id
 * @return {Promise}
 */


export var syncPixels = function syncPixels(mcvid) {
  // check if we have a Marketing Cloud Visitor Id before continuing
  if (!mcvid) return Promise.resolve(); // check if pixels ids are configured before continuing

  var _ref2 = getConfig() || {},
      facebookPixelId = _ref2.facebookPixelId,
      googleAdsPixelId = _ref2.googleAdsPixelId;

  if (!facebookPixelId && !googleAdsPixelId) return Promise.resolve(); // if we have a MCVID and pixels are configured, proceed to sync pixels

  return window.fetch(createSyncPixelsUrl(mcvid)).then(function (res) {
    return res.json();
  }).then(extractStringIds).then(function (stringIds) {
    if (stringIds) {
      var ids = stringIds.split(/(\d+)/).map(function (str) {
        return +str;
      }).filter(Boolean);
      return Promise.all([syncWithGoogle(googleAdsPixelId, ids), syncWithFacebook(facebookPixelId, ids)]);
    }
  });
};
